@@ -3,9 +3,8 @@ package main
 import (
 	"errors"
 	"fmt"
-	"log"
 	"os"
-	"os/exec"
+	"path/filepath"
 
 	"github.com/noborus/ov/oviewer"
 	"github.com/spf13/cobra"
@@ -82,6 +81,15 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
 		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
 
+		if config.FileLoadChunksLimit >= 0 && config.FileLoadChunksLimit < 2 {
+			config.FileLoadChunksLimit = 2
+		}
+		oviewer.FileLoadChunksLimit = config.FileLoadChunksLimit
+		if config.LoadChunksLimit >= 0 && config.LoadChunksLimit < 2 {
+			config.LoadChunksLimit = 2
+		}
+		oviewer.LoadChunksLimit = config.LoadChunksLimit
+
 		SetRedirect()
 
 		if execCommand {
@@ -141,23 +149,14 @@ func ExecCommand(args []string) error {
 	if len(args) == 0 {
 		return ErrNoArgument
 	}
-
-	command := exec.Command(args[0], args[1:]...)
-	ov, err := oviewer.ExecCommand(command)
+	cmd := oviewer.NewCommand(args...)
+	ov, err := cmd.Exec()
 	if err != nil {
 		return err
 	}
 
 	defer func() {
-		if command == nil || command.Process == nil {
-			return
-		}
-		if err := command.Process.Kill(); err != nil {
-			log.Println(err)
-		}
-		if err := command.Wait(); err != nil {
-			log.Println(err)
-		}
+		cmd.Wait()
 	}()
 
 	ov.SetConfig(config)
@@ -204,7 +203,7 @@ func init() {
 	config = oviewer.NewConfig()
 	cobra.OnInitialize(initConfig)
 
-	rootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", "config file (default is $HOME/.ov.yaml)")
+	rootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", "config file (default is $XDG_CONFIG_HOME/ov/config.yaml)")
 	_ = rootCmd.RegisterFlagCompletionFunc("config", func(_ *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
 		return []string{"yaml"}, cobra.ShellCompDirectiveFilterFileExt
 	})
@@ -242,6 +241,9 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("column-mode", "c", false, "column mode")
 	_ = viper.BindPFlag("general.ColumnMode", rootCmd.PersistentFlags().Lookup("column-mode"))
 
+	rootCmd.PersistentFlags().BoolP("column-width", "", false, "column width mode")
+	_ = viper.BindPFlag("general.ColumnWidth", rootCmd.PersistentFlags().Lookup("column-width"))
+
 	rootCmd.PersistentFlags().BoolP("column-rainbow", "", false, "column rainbow")
 	_ = viper.BindPFlag("general.ColumnRainbow", rootCmd.PersistentFlags().Lookup("column-rainbow"))
 
@@ -275,6 +277,9 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("follow-section", "", false, "follow section")
 	_ = viper.BindPFlag("general.FollowSection", rootCmd.PersistentFlags().Lookup("follow-section"))
 
+	rootCmd.PersistentFlags().BoolP("follow-name", "", false, "follow name mode")
+	_ = viper.BindPFlag("general.FollowName", rootCmd.PersistentFlags().Lookup("follow-name"))
+
 	rootCmd.PersistentFlags().IntP("watch", "T", 0, "watch mode interval")
 	_ = viper.BindPFlag("general.WatchInterval", rootCmd.PersistentFlags().Lookup("watch"))
 
@@ -312,6 +317,12 @@ func init() {
 	rootCmd.PersistentFlags().StringP("view-mode", "", "", "view mode")
 	_ = viper.BindPFlag("ViewMode", rootCmd.PersistentFlags().Lookup("view-mode"))
 
+	rootCmd.PersistentFlags().IntP("load-limit", "", -1, "Limit loading chunks")
+	_ = viper.BindPFlag("LoadChunksLimit", rootCmd.PersistentFlags().Lookup("load-limit"))
+
+	rootCmd.PersistentFlags().IntP("file-load-limit", "", 100, "Limit chunks loading files into memory")
+	_ = viper.BindPFlag("FileLoadChunksLimit", rootCmd.PersistentFlags().Lookup("file-load-limit"))
+
 	rootCmd.PersistentFlags().BoolP("debug", "", false, "debug mode")
 	_ = viper.BindPFlag("Debug", rootCmd.PersistentFlags().Lookup("debug"))
 }
@@ -322,16 +333,37 @@ func initConfig() {
 		// Use config file from the flag.
 		viper.SetConfigFile(cfgFile)
 	} else {
-		// Find home directory.
+		// Get home directory.
 		home, err := os.UserHomeDir()
 		if err != nil {
 			fmt.Fprintln(os.Stderr, err)
 			return
 		}
 
-		// Search config in home directory with name ".ov" (without extension).
-		viper.AddConfigPath(home)
-		viper.SetConfigName(".ov")
+		// Get XDG config directory.
+		xdgConfigHome := os.Getenv("XDG_CONFIG_HOME")
+
+		var defaultConfigPath string
+
+		if xdgConfigHome != "" {
+			// If set, use it for the default configuration path.
+			defaultConfigPath = filepath.Join(xdgConfigHome, "ov")
+		} else {
+			// If not set, use the default `$HOME/.config/ov`.
+			defaultConfigPath = filepath.Join(home, ".config", "ov")
+		}
+
+		// Set the default configuration path and file name.
+		viper.AddConfigPath(defaultConfigPath)
+		viper.SetConfigName("config")
+
+		// If the default config file does not exist but the legacy config file does exist,
+		// then fallback to the legacy config path and file name.
+		if !fileExists(filepath.Join(defaultConfigPath, "config.yaml")) &&
+			fileExists(filepath.Join(home, ".ov.yaml")) {
+			viper.AddConfigPath(home)
+			viper.SetConfigName(".ov")
+		}
 	}
 
 	viper.AutomaticEnv() // read in environment variables that match
@@ -344,6 +376,13 @@ func initConfig() {
 	}
 }
 
+func fileExists(path string) bool {
+	if _, err := os.Stat(path); errors.Is(err, os.ErrNotExist) {
+		return false
+	}
+	return true
+}
+
 func main() {
 	if err := rootCmd.Execute(); err != nil {
 		os.Exit(1)
