@@ -19,7 +19,7 @@ func (root *Root) eventLoop(ctx context.Context, quitChan chan<- struct{}) {
 		atomic.StoreInt32(&root.Doc.watchRestart, 1)
 	}
 	go root.updateInterval(ctx)
-
+	defer root.debugNumOfChunk()
 	for {
 		if root.General.FollowAll || root.Doc.FollowMode || root.Doc.FollowSection {
 			root.follow()
@@ -147,7 +147,7 @@ type eventAppSuspend struct {
 	tcell.EventTime
 }
 
-// Suspend fires the eventAppsuspend event.
+// Suspend fires the eventAppSuspend event.
 func (root *Root) Suspend() {
 	if !root.checkScreen() {
 		return
@@ -177,9 +177,6 @@ func (root *Root) follow() {
 	if root.General.FollowAll {
 		root.followAll()
 	}
-
-	root.Doc.onceFollowMode()
-
 	num := root.Doc.BufEndNum()
 	if root.Doc.latestNum == num {
 		return
@@ -202,10 +199,8 @@ func (root *Root) followAll() {
 	}
 
 	current := root.CurrentDoc
-
 	root.mu.RLock()
 	for n, doc := range root.DocList {
-		doc.onceFollowMode()
 		if doc.latestNum != doc.BufEndNum() {
 			current = n
 		}
@@ -213,7 +208,6 @@ func (root *Root) followAll() {
 	root.mu.RUnlock()
 
 	if root.CurrentDoc != current {
-		log.Printf("switch document: %d", current)
 		root.switchDocument(current)
 	}
 }
