@@ -2,7 +2,7 @@ package oviewer
 
 import (
 	"log"
-	"strings"
+	"sync/atomic"
 )
 
 // NewLogDoc generates a document for log.
@@ -13,16 +13,30 @@ func NewLogDoc() (*Document, error) {
 		return nil, err
 	}
 	m.FollowMode = true
-	m.FileName = "Log"
+	m.Caption = "Log"
 	m.seekable = false
 	log.SetOutput(m)
+	atomic.StoreInt32(&m.closed, 1)
+	if err := m.ControlLog(); err != nil {
+		return nil, err
+	}
 	return m, nil
 }
 
 // Write matches the interface of io.Writer(so package log is possible).
 // Therefore, the log.Print output is displayed by logDoc.
 func (m *Document) Write(p []byte) (int, error) {
-	str := strings.TrimSuffix(string(p), "\n")
-	m.append(str)
-	return len(str), nil
+	chunk := m.chunkForAdd()
+	m.append(chunk, p)
+	if len(chunk.lines) >= ChunkSize {
+		chunk = NewChunk(m.size)
+		m.mu.Lock()
+		if len(m.chunks) > 2 {
+			m.chunks[len(m.chunks)-2].lines = nil
+			m.startNum = ChunkSize * (len(m.chunks) - 1)
+		}
+		m.chunks = append(m.chunks, chunk)
+		m.mu.Unlock()
+	}
+	return len(p), nil
 }
